from prettyqt.qt import QtWidgets


class StyleOption(QtWidgets.QStyleOption):
    pass
